@@ -85,7 +85,7 @@ class Container
      * names or partials - just so long as it's something that can be mocked.
      * I'll refactor it one day so it's easier to follow.
      *
-     * @param array $args
+     * @param array ...$args
      *
      * @return Mock
      * @throws Exception\RuntimeException
@@ -96,6 +96,7 @@ class Container
         $quickdefs = array();
         $constructorArgs = null;
         $blocks = array();
+        $class = null;
 
         if (count($args) > 1) {
             $finalArg = end($args);
@@ -116,6 +117,7 @@ class Container
         reset($args);
 
         $builder->setParameterOverrides(\Mockery::getConfiguration()->getInternalClassMethodParamMaps());
+        $builder->setConstantsMap(\Mockery::getConfiguration()->getConstantsMap());
 
         while (count($args) > 0) {
             $arg = current($args);
@@ -147,9 +149,15 @@ class Container
                 }
                 $class = $parts[0];
                 $parts[1] = str_replace(' ', '', $parts[1]);
-                $partialMethods = explode(',', strtolower(rtrim($parts[1], ']')));
+                $partialMethods = array_filter(explode(',', strtolower(rtrim($parts[1], ']'))));
                 $builder->addTarget($class);
-                $builder->setWhiteListedMethods($partialMethods);
+                foreach ($partialMethods as $partialMethod) {
+                    if ($partialMethod[0] === '!') {
+                        $builder->addBlackListedMethod(substr($partialMethod, 1));
+                        continue;
+                    }
+                    $builder->addWhiteListedMethod($partialMethod);
+                }
                 array_shift($args);
                 continue;
             } elseif (is_string($arg) && (class_exists($arg, true) || interface_exists($arg, true) || trait_exists($arg, true))) {
@@ -191,7 +199,6 @@ class Container
         $builder->addBlackListedMethods($blocks);
 
         if (defined('HHVM_VERSION')
-            && isset($class)
             && ($class === 'Exception' || is_subclass_of($class, 'Exception'))) {
             $builder->addBlackListedMethod("setTraceOptions");
             $builder->addBlackListedMethod("getTraceOptions");
@@ -215,7 +222,7 @@ class Container
 
         if (class_exists($def->getClassName(), $attemptAutoload = false)) {
             $rfc = new \ReflectionClass($def->getClassName());
-            if (!$rfc->implementsInterface("Mockery\MockInterface")) {
+            if (!$rfc->implementsInterface("Mockery\LegacyMockInterface")) {
                 throw new \Mockery\Exception\RuntimeException("Could not load mock {$def->getClassName()}, class already exists");
             }
         }
@@ -223,7 +230,7 @@ class Container
         $this->getLoader()->load($def);
 
         $mock = $this->_getInstance($def->getClassName(), $constructorArgs);
-        $mock->mockery_init($this, $config->getTargetObject());
+        $mock->mockery_init($this, $config->getTargetObject(), $config->isInstanceMock());
 
         if (!empty($quickdefs)) {
             $mock->shouldReceive($quickdefs)->byDefault();
@@ -251,12 +258,13 @@ class Container
 
     /**
      * @param string $method
+     * @param string $parent
      * @return string|null
      */
-    public function getKeyOfDemeterMockFor($method)
+    public function getKeyOfDemeterMockFor($method, $parent)
     {
         $keys = array_keys($this->_mocks);
-        $match = preg_grep("/__demeter_{$method}$/", $keys);
+        $match = preg_grep("/__demeter_" . md5($parent) . "_{$method}$/", $keys);
         if (count($match) == 1) {
             $res = array_values($match);
             if (count($res) > 0) {
@@ -393,7 +401,7 @@ class Container
      * @throws \Mockery\Exception
      * @return void
      */
-    public function mockery_validateOrder($method, $order, \Mockery\MockInterface $mock)
+    public function mockery_validateOrder($method, $order, \Mockery\LegacyMockInterface $mock)
     {
         if ($order < $this->_currentOrder) {
             $exception = new \Mockery\Exception\InvalidOrderException(
@@ -426,10 +434,10 @@ class Container
     /**
      * Store a mock and set its container reference
      *
-     * @param \Mockery\Mock
-     * @return \Mockery\MockInterface
+     * @param \Mockery\Mock $mock
+     * @return \Mockery\LegacyMockInterface|\Mockery\MockInterface
      */
-    public function rememberMock(\Mockery\MockInterface $mock)
+    public function rememberMock(\Mockery\LegacyMockInterface $mock)
     {
         if (!isset($this->_mocks[get_class($mock)])) {
             $this->_mocks[get_class($mock)] = $mock;
