@@ -1,8 +1,27 @@
 <?php
+/**
+ * Mockery
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://github.com/padraic/mockery/blob/master/LICENSE
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to padraic@php.net so we can send you a copy immediately.
+ *
+ * @category   Mockery
+ * @package    Mockery
+ * @copyright  Copyright (c) 2010 Pádraic Brady (http://blog.astrumfutura.com)
+ * @license    http://github.com/padraic/mockery/blob/master/LICENSE New BSD License
+ */
 
 namespace Mockery\Generator\StringManipulation\Pass;
 
 use Mockery\Generator\Method;
+use Mockery\Generator\Parameter;
 use Mockery\Generator\MockConfiguration;
 
 class MethodDefinitionPass implements Pass
@@ -49,7 +68,7 @@ class MethodDefinitionPass implements Pass
         $methodParams = array();
         $params = $method->getParameters();
         foreach ($params as $param) {
-            $paramDef = $param->getTypeHintAsString();
+            $paramDef = $this->renderTypeHint($param);
             $paramDef .= $param->isPassedByReference() ? '&' : '';
             $paramDef .= $param->isVariadic() ? '...' : '';
             $paramDef .= '$' . $param->getName();
@@ -80,6 +99,23 @@ class MethodDefinitionPass implements Pass
         return $class;
     }
 
+    protected function renderTypeHint(Parameter $param)
+    {
+        $typeHint = trim($param->getTypeHintAsString());
+
+        if (!empty($typeHint)) {
+            if (!\Mockery::isBuiltInType($typeHint)) {
+                $typeHint = '\\'.$typeHint;
+            }
+
+            if (version_compare(PHP_VERSION, '7.1.0-dev') >= 0 && $param->allowsNull()) {
+                $typeHint = "?".$typeHint;
+            }
+        }
+
+        return $typeHint .= ' ';
+    }
+
     private function renderMethodBody($method, $config)
     {
         $invoke = $method->isStatic() ? 'static::_mockery_handleStaticMethodCall' : '$this->_mockery_handleMethodCall';
@@ -126,11 +162,14 @@ if (\$argc > $i) {
 BODY;
             }
         }
-        $body .= <<<BODY
-\$ret = {$invoke}(__FUNCTION__, \$argv);
-return \$ret;
-}
-BODY;
+
+        $body .= "\$ret = {$invoke}(__FUNCTION__, \$argv);\n";
+
+        if ($method->getReturnType() !== "void") {
+            $body .= "return \$ret;\n";
+        }
+
+        $body .= "}\n";
         return $body;
     }
 }
