@@ -1,7 +1,7 @@
 <?php
 
+use Mockery\Matcher\AndAnyOtherArgs;
 use Mockery\Matcher\AnyArgs;
-use Mockery\Matcher\NoArgs;
 
 /**
  * Mockery
@@ -25,21 +25,21 @@ use Mockery\Matcher\NoArgs;
 if (!function_exists("mock")) {
     function mock(...$args)
     {
-        return call_user_func_array([Mockery::class, "mock"], $args);
+        return Mockery::mock(...$args);
     }
 }
 
 if (!function_exists("spy")) {
     function spy(...$args)
     {
-        return call_user_func_array([Mockery::class, "spy"], $args);
+        return Mockery::spy(...$args);
     }
 }
 
 if (!function_exists("namedMock")) {
     function namedMock(...$args)
     {
-        return call_user_func_array([Mockery::class, "namedMock"], $args);
+        return Mockery::namedMock(...$args);
     }
 }
 
@@ -49,3 +49,17 @@ if (!function_exists("anyArgs")) {
         return new AnyArgs();
     }
 }
+
+if (!function_exists("andAnyOtherArgs")) {
+    function andAnyOtherArgs()
+    {
+        return new AndAnyOtherArgs();
+    }
+}
+
+if (!function_exists("andAnyOthers")) {
+    function andAnyOthers()
+    {
+        return new AndAnyOtherArgs();
+    }
+}
